@@ -21,6 +21,7 @@
 #include "musicaudiotrack.h"
 #include "databaseinterface.h"
 #include "albummodel.h"
+#include "modeltest.h"
 
 #include <QObject>
 #include <QUrl>
@@ -141,6 +142,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
+        ModelTest testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -192,6 +194,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
+        ModelTest testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -254,6 +257,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
+        ModelTest testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -347,6 +351,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
+        ModelTest testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -393,7 +398,7 @@ private Q_SLOTS:
             QTime::fromMSecsSinceStartOfDay(3), {QUrl::fromLocalFile(QStringLiteral("/$3"))},
             {QUrl::fromLocalFile(QStringLiteral("file://image$3"))}, 5, true};
 
-        musicDb.modifyTracksList({modifiedTrack}, mNewCovers);
+        musicDb.modifyTracksList({modifiedTrack}, mNewCovers, QStringLiteral("autoTest"));
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
