@@ -22,6 +22,7 @@
 
 #include "musicaudiotrack.h"
 #include "musicalbum.h"
+#include "musicartist.h"
 
 #include <QAbstractListModel>
 #include <QVector>
@@ -32,6 +33,7 @@ class MediaPlayListPrivate;
 class DatabaseInterface;
 class MusicListenersManager;
 class MediaPlayListEntry;
+class QDebug;
 
 class MediaPlayList : public QAbstractListModel
 {
@@ -76,19 +78,30 @@ public:
         TitleRole,
         DurationRole,
         MilliSecondsDurationRole,
-        CreatorRole,
+        TrackDataRole,
         ArtistRole,
         AlbumArtistRole,
         AlbumRole,
         TrackNumberRole,
         DiscNumberRole,
         RatingRole,
+        GenreRole,
+        LyricistRole,
+        ComposerRole,
+        CommentRole,
+        YearRole,
+        ChannelsRole,
+        BitRateRole,
+        SampleRateRole,
         ImageRole,
         ResourceRole,
         CountRole,
         IsPlayingRole,
         HasAlbumHeader,
         IsSingleDiscAlbumHeader,
+        SecondaryTextRole,
+        ImageUrlRole,
+        ShadowForImageRole,
     };
 
     Q_ENUM(ColumnsRoles)
@@ -121,6 +134,8 @@ public:
 
     Q_INVOKABLE void clearPlayList();
 
+    Q_INVOKABLE bool savePlaylist(const QUrl &fileName);
+
     QVariantMap persistentState() const;
 
     MusicListenersManager* musicListenersManager() const;
@@ -139,6 +154,8 @@ Q_SIGNALS:
 
     void newTrackByNameInList(const QString &title, const QString &artist, const QString &album, int trackNumber, int discNumber);
 
+    void newTrackByFileNameInList(const QUrl &fileName);
+
     void newTrackByIdInList(qulonglong newTrackId);
 
     void newArtistInList(const QString &artist);
@@ -161,6 +178,10 @@ Q_SIGNALS:
 
     void playListFinished();
 
+    void playListLoaded();
+
+    void playListLoadFailed();
+
 public Q_SLOTS:
 
     void setPersistentState(const QVariantMap &persistentState);
@@ -187,6 +208,8 @@ public Q_SLOTS:
 
     void switchTo(int row);
 
+    void loadPlaylist(const QUrl &fileName);
+
     void enqueue(qulonglong newTrackId);
 
     void enqueue(const MusicAudioTrack &newTrack);
@@ -195,24 +218,38 @@ public Q_SLOTS:
 
     void enqueue(const MusicAlbum &album);
 
+    void enqueue(const MusicArtist &artist);
+
     void enqueue(const QString &artistName);
 
+    void enqueue(const QUrl &fileName);
+
+    void enqueue(const QStringList &files);
+
     void clearAndEnqueue(qulonglong newTrackId);
 
     void clearAndEnqueue(const MusicAudioTrack &newTrack);
 
     void clearAndEnqueue(const MusicAlbum &album);
 
+    void clearAndEnqueue(const MusicArtist &artist);
+
     void clearAndEnqueue(const QString &artistName);
 
+    void clearAndEnqueue(const QUrl &fileName);
+
     void trackInError(QUrl sourceInError, QMediaPlayer::Error playerError);
 
 private Q_SLOTS:
 
-    bool rowHasHeader(int row) const;
+    void loadPlayListLoaded();
+
+    void loadPlayListLoadFailed();
 
 private:
 
+    bool rowHasHeader(int row) const;
+
     void resetCurrentTrack();
 
     void notifyCurrentTrackChanged();
@@ -250,6 +287,9 @@ public:
     explicit MediaPlayListEntry(QString artist) : mArtist(std::move(artist)), mIsArtist(true) {
     }
 
+    explicit MediaPlayListEntry(QUrl fileName) : mTrackUrl(std::move(fileName)) {
+    }
+
     QString mTitle;
 
     QString mAlbum;
@@ -272,6 +312,8 @@ public:
 
 };
 
+QDebug operator<<(QDebug stream, const MediaPlayListEntry &data);
+
 
 
 #endif // MEDIAPLAYLIST_H
