@@ -20,9 +20,14 @@
 #include "trackslistener.h"
 
 #include "databaseinterface.h"
+#include "elisautils.h"
 
+#include <KFileMetaData/ExtractorCollection>
+
+#include <QMimeDatabase>
 #include <QSet>
 #include <QList>
+#include <QDebug>
 
 #include <array>
 #include <algorithm>
@@ -35,8 +40,14 @@ public:
 
     QList<std::tuple<QString, QString, QString, int, int>> mTracksByNameSet;
 
+    QList<QUrl> mTracksByFileNameSet;
+
     DatabaseInterface *mDatabase = nullptr;
 
+    KFileMetaData::ExtractorCollection mExtractors;
+
+    QMimeDatabase mMimeDb;
+
 };
 
 TracksListener::TracksListener(DatabaseInterface *database, QObject *parent) : QObject(parent), d(std::make_unique<TracksListenerPrivate>())
@@ -125,6 +136,40 @@ void TracksListener::trackByNameInList(const QString &title, const QString &arti
     }
 }
 
+void TracksListener::trackByFileNameInList(const QUrl &fileName)
+{
+    qDebug() << "TracksListener::trackByFileNameInList" << fileName;
+    auto newTrackId = d->mDatabase->trackIdFromFileName(fileName);
+    qDebug() << "TracksListener::trackByFileNameInList" << fileName << newTrackId;
+    if (newTrackId == 0) {
+        auto newTrack = scanOneFile(fileName);
+
+        qDebug() << "TracksListener::trackByFileNameInList" << fileName << newTrack;
+
+        if (newTrack.isValid()) {
+            qDebug() << "TracksListener::trackByFileNameInList" << "trackHasChanged" << newTrack;
+            Q_EMIT trackHasChanged(newTrack);
+
+            return;
+        }
+
+        d->mTracksByFileNameSet.push_back(fileName);
+
+        return;
+    }
+
+    d->mTracksByIdSet.insert(newTrackId);
+
+    auto newTrack = d->mDatabase->trackFromDatabaseId(newTrackId);
+
+    qDebug() << "TracksListener::trackByFileNameInList" << newTrackId << newTrack;
+
+    if (newTrack.isValid()) {
+        qDebug() << "TracksListener::trackByFileNameInList" << "trackHasChanged" << newTrack;
+        Q_EMIT trackHasChanged(newTrack);
+    }
+}
+
 void TracksListener::trackByIdInList(qulonglong newTrackId)
 {
     d->mTracksByIdSet.insert(newTrackId);
@@ -149,5 +194,10 @@ void TracksListener::newArtistInList(const QString &artist)
     Q_EMIT albumAdded(newTracks);
 }
 
+MusicAudioTrack TracksListener::scanOneFile(const QUrl &scanFile)
+{
+    return ElisaUtils::scanOneFile(scanFile, d->mMimeDb, d->mExtractors);
+}
+
 
 #include "moc_trackslistener.cpp"
